@@ -15,9 +15,10 @@ pingpong_thrift = thriftpy2.load("pingpong.thrift")
 
 
 client = make_client(pingpong_thrift.PingPong, '127.0.0.1', 6000)
+
 # print(client.ping())
-
+#
 print(client.func())
-
-
-print(client.func('xx'))
\ No newline at end of file
+#
+#
+# print(client.func('xx'))
\ No newline at end of file
