@@ -8,4 +8,5 @@
 # @Software     : PyCharm
 # @Description  : 
 
-
+from appzoo.grpc_app.service import Service
+from appzoo.grpc_app.client import Client
