@@ -10,8 +10,8 @@
 
 
 import grpc
-from appzoo.grpc_app.base_pb2 import Request, Response
-from appzoo.grpc_app.base_pb2_grpc import GrpcServiceServicer, GrpcServiceStub, add_GrpcServiceServicer_to_server
+from appzoo.grpc_app.protos.base_pb2 import Request, Response
+from appzoo.grpc_app.protos.base_pb2_grpc import GrpcServiceServicer, GrpcServiceStub, add_GrpcServiceServicer_to_server
 
 from meutils.pipe import *
 from pickle import dumps, loads
@@ -23,7 +23,7 @@ class Service(GrpcServiceServicer):
         self.debug = debug
 
     def main(self, *args, **kwargs):
-        raise NotImplementedError
+        raise NotImplementedError('Method not implemented!')
 
     @logger.catch()
     def _request(self, request, context):
@@ -35,18 +35,23 @@ class Service(GrpcServiceServicer):
         return Response(data=output)
 
     def run(self, port=8000, max_workers=3):
-
-        server = grpc.server(ThreadPoolExecutor(max_workers))  # compression = None
+        options = [
+            ('grpc.max_send_message_length', 32 * 1024 * 1024),  # 32 MB
+            ('grpc.max_receive_message_length', 32 * 1024 * 1024)
+        ]
+        server = grpc.server(ThreadPoolExecutor(max_workers), options=options)  # compression = None
         add_GrpcServiceServicer_to_server(self, server)
 
         server.add_insecure_port(f'[::]:{port}')
         server.start()
         logger.info("GrpcService Running ...")
-        try:
-            while 1:
-                time.sleep(60 * 60 * 24)
-        except KeyboardInterrupt:
-            server.stop(0)
+        server.wait_for_termination()
+
+        # try:
+        #     while 1:
+        #         time.sleep(60 * 60 * 24)
+        # except KeyboardInterrupt:
+        #     server.stop(0)
 
 
 if __name__ == '__main__':
@@ -56,4 +61,4 @@ if __name__ == '__main__':
             return data
 
 
-    MyService(debug=True).run()
+    MyService(debug=False).run()
