@@ -28,9 +28,9 @@ app_ = app.app
 #     print(kwargs)
 #     r = requests.request(**kwargs)
 #     return r.json()
+#l;=]
 #
-#
-# app.add_route_plus(proxy_app_, methods=["GET", "POST"], data=None)
+# app.add_route_plus(proxy_app_, methods=["GET", "POST"], data=None)f j a
 
 import time
 
@@ -41,3 +41,18 @@ app.add_route_plus(f, methods=["GET", "POST"], data=None)
 
 if __name__ == '__main__':
     app.run(app.app_from(__file__), port=9955, debug=True)
+
+
+from docarray import Document, DocumentArray
+
+d = Document(uri='https://www.gutenberg.org/files/1342/1342-0.txt').load_uri_to_text()
+da = DocumentArray(Document(text=s.strip()) for s in d.text.split('\n') if s.strip())
+da.apply(Document.embed_feature_hashing, backend='process')
+
+q = (
+    Document(text='she smiled too much')
+    .embed_feature_hashing()
+    .match(da, metric='jaccard', use_scipy=True)
+)
+
+print(q.matches[:5, ('text', 'scores__jaccard__value')])
\ No newline at end of file
